@@ -106,7 +106,7 @@ var availableServices = {
     },
     email: {
         action: "email",
-        name: _("E-Mail (WinMobile < 7, iPhone, iPad)"),
+        name: _("E-Mail (WinMobile, iPhone, iPad)"),
         listCaption: _("Select an E-Mail address or edit the address in the field below."),
         inputCaption: _("Address to send mobile configuration link to:"),
         defaultFields: ["email1", "email2", "email3"],
